summaryrefslogtreecommitdiffstats
path: root/tqtinterface/qt4/src/opengl/tqgl_x11.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'tqtinterface/qt4/src/opengl/tqgl_x11.cpp')
-rw-r--r--tqtinterface/qt4/src/opengl/tqgl_x11.cpp28
1 files changed, 14 insertions, 14 deletions
diff --git a/tqtinterface/qt4/src/opengl/tqgl_x11.cpp b/tqtinterface/qt4/src/opengl/tqgl_x11.cpp
index 70abe7d..2bedfd6 100644
--- a/tqtinterface/qt4/src/opengl/tqgl_x11.cpp
+++ b/tqtinterface/qt4/src/opengl/tqgl_x11.cpp
@@ -68,7 +68,7 @@
extern "C" {
Status XmuLookupStandardColormap( Display *dpy, int screen, VisualID visualid,
unsigned int depth, Atom property,
- Bool tqreplace, Bool retain );
+ Bool replace, Bool retain );
}
#endif
@@ -189,7 +189,7 @@ bool qt_resolve_gl_symbols(bool fatal)
/*
The choose_cmap function is internal and used by TQGLWidget::setContext()
- and GLX (not Windows). If the application can't tqfind any sharable
+ and GLX (not Windows). If the application can't find any sharable
colormaps, it must at least create as few colormaps as possible. The
dictionary solution below ensures only one colormap is created per visual.
Colormaps are also deleted when the application terminates.
@@ -244,7 +244,7 @@ static Colormap choose_cmap( Display *dpy, XVisualInfo *vi )
qAddPostRoutine( cleanup_cmaps );
}
- CMapEntry *x = cmap_dict->tqfind( (long) vi->visualid + ( vi->screen * 256 ) );
+ CMapEntry *x = cmap_dict->find( (long) vi->visualid + ( vi->screen * 256 ) );
if ( x ) // found colormap for visual
return x->cmap;
@@ -284,7 +284,7 @@ static Colormap choose_cmap( Display *dpy, XVisualInfo *vi )
if ( !x->cmap ) {
#ifdef TQT_DLOPEN_OPENGL
typedef Status (*_XmuLookupStandardColormap)( Display *dpy, int screen, VisualID visualid, unsigned int depth,
- Atom property, Bool tqreplace, Bool retain );
+ Atom property, Bool replace, Bool retain );
_XmuLookupStandardColormap qt_XmuLookupStandardColormap;
qt_XmuLookupStandardColormap = (_XmuLookupStandardColormap) TQLibrary::resolve("Xmu.so.6", "XmuLookupStandardColormap");
if (!qt_XmuLookupStandardColormap)
@@ -334,7 +334,7 @@ static TQMemArray<TransColor> trans_colors;
static int trans_colors_init = FALSE;
-static void tqfind_trans_colors()
+static void find_trans_colors()
{
struct OverlayProp {
long visual;
@@ -407,7 +407,7 @@ bool TQGLFormat::hasOpenGLOverlays()
{
qt_resolve_gl_symbols();
if ( !trans_colors_init )
- tqfind_trans_colors();
+ find_trans_colors();
return trans_colors.size() > 0;
}
@@ -508,7 +508,7 @@ bool TQGLContext::chooseContext( const TQGLContext* shareContext )
/*!
- <strong>X11 only</strong>: This virtual function tries to tqfind a
+ <strong>X11 only</strong>: This virtual function tries to find a
visual that matches the format, reducing the demands if the original
request cannot be met.
@@ -599,12 +599,12 @@ void *TQGLContext::tryVisual( const TQGLFormat& f, int bufDepth )
if ( f.plane() && !useTranspExtChecked && d->paintDevice ) {
TQCString estr( glXQueryExtensionsString( d->paintDevice->x11Display(),
d->paintDevice->x11Screen() ) );
- useTranspExt = estr.tqcontains( "GLX_EXT_visual_info" );
+ useTranspExt = estr.contains( "GLX_EXT_visual_info" );
//# (A bit simplistic; that could theoretically be a substring)
if ( useTranspExt ) {
TQCString cstr( glXGetClientString( d->paintDevice->x11Display(),
GLX_VENDOR ) );
- useTranspExt = !cstr.tqcontains( "Xi Graphics" ); // bug workaround
+ useTranspExt = !cstr.contains( "Xi Graphics" ); // bug workaround
if ( useTranspExt ) {
// bug workaround - some systems (eg. FireGL) refuses to return an overlay
// visual if the GLX_TRANSPARENT_TYPE_EXT attribute is specfied, even if
@@ -747,7 +747,7 @@ TQColor TQGLContext::overlayTransparentColor() const
//### make more efficient using the transpColor member
if ( isValid() ) {
if ( !trans_colors_init )
- tqfind_trans_colors();
+ find_trans_colors();
VisualID myVisualId = ((XVisualInfo*)vi)->visualid;
int myScreen = ((XVisualInfo*)vi)->screen;
@@ -785,7 +785,7 @@ uint TQGLContext::colorIndex( const TQColor& c ) const
return c.pixel( screen ); // We're using TQColor's cmap
XVisualInfo *info = (XVisualInfo *) vi;
- CMapEntry *x = cmap_dict->tqfind( (long) info->visualid + ( info->screen * 256 ) );
+ CMapEntry *x = cmap_dict->find( (long) info->visualid + ( info->screen * 256 ) );
if ( x && !x->alloc) { // It's a standard colormap
int rf = (int)(((float)c.red() * (x->scmap.red_max+1))/256.0);
int gf = (int)(((float)c.green() * (x->scmap.green_max+1))/256.0);
@@ -800,7 +800,7 @@ uint TQGLContext::colorIndex( const TQColor& c ) const
qglcmap_dict = new TQIntDict< TQMap<int, TQRgb> >;
}
TQMap<int, TQRgb> *cmap;
- if ((cmap = qglcmap_dict->tqfind((long) info->visualid)) == 0) {
+ if ((cmap = qglcmap_dict->find((long) info->visualid)) == 0) {
cmap = new TQMap<int, TQRgb>;
qglcmap_dict->insert((long) info->visualid, cmap);
}
@@ -1177,7 +1177,7 @@ void TQGLWidget::setContext( TQGLContext *context,
XVisualInfo *vi = (XVisualInfo*)glcx->vi;
XSetWindowAttributes a;
- a.colormap = choose_cmap( x11Display(), vi ); // tqfind best colormap
+ a.colormap = choose_cmap( x11Display(), vi ); // find best colormap
a.background_pixel = backgroundColor().pixel( vi->screen );
a.border_pixel = TQt::black.pixel( vi->screen );
Window p = RootWindow( x11Display(), vi->screen );
@@ -1198,7 +1198,7 @@ void TQGLWidget::setContext( TQGLContext *context,
XFree( (char *)cmwret );
int i;
for ( i=0; i<count; i++ ) {
- if ( cmw[i] == winId() ) { // tqreplace old window
+ if ( cmw[i] == winId() ) { // replace old window
cmw[i] = w;
break;
}